"""
Components service
"""
from typing import List

from portal import logger
from portal.database.models import Worker
from portal.service import general

log = logger.get_logger(__name__)


def _set_worker_data(worker: Worker, data: dict) -> Worker:
    allowed = ['name', 'url', 'tags', 'portal_secret']
    return general.update_entity(worker, data, allowed=allowed)


class WorkerService:
    def __init__(self, worker: Worker = None):
        self._worker = worker

    @property
    def worker(self):
        return self._worker

    def create_worker(self, **data):
        """Create worker
        Keyword Args:
            name(str): Name of the submission
            url(str): Address where the worker is accessible
        """
        worker = Worker(name=data['name'], url=data['url'])
        self._worker = Worker
        _set_worker_data(worker, data)
        log.info(f"[CREATE] Worker({worker.id}): {data}")
        return worker

    def update_worker(self, data: dict) -> Worker:
        """Update worker
        Args:
            data(dict): Data used for the update

        Returns(Worker): Updated worker instance

        """
        log.info(f"[UPDATE] Worker: {self.worker.id}: {data}")
        return _set_worker_data(worker=self.worker, data=data)

    def delete_worker(self):
        """Delete worker
        Args:
            worker(Worker): Worker instance
        """
        log.info(f"[DELETE] Worker: {self.worker.id} ({self.worker.name})")
        general.delete_entity(self.worker)

    def find_all_workers(self) -> List[Worker]:
        """Gets list of tall workers
        Returns(list): List of workers
        """
        return Worker.query.all()
