import json

import pytest

from tests.rest import utils


@pytest.fixture
def student_credentials():
    return json.dumps({
        "type": "username_password",
        "identifier": "student1",
        "secret": "123456"
    })


@pytest.fixture
def worker_credentials():
    return json.dumps({
        "type": "secret",
        "identifier": "executor",
        "secret": "executor_secret"
    })


def test_client_detail_using_student_cred(client, student_credentials):
    path = f'/client'
    response = utils.make_request(
        client, path, 'get', credentials=student_credentials)
    print(f"Response: {response.data}")
    assert response.status_code == 200
    assert response.mimetype == 'application/json'
    data = response.json
    assert data['username'] == 'student1'
    assert data['type'] == 'ClientType.USER'


def test_client_detail_using_executor_cred(client, worker_credentials):
    path = f'/client'
    response = utils.make_request(
        client, path, 'get', credentials=worker_credentials)
    print(f"Response: {response.data}")
    assert response.status_code == 200
    assert response.mimetype == 'application/json'
    data = response.json
    assert data['name'] == 'executor'
    assert data['type'] == 'ClientType.WORKER'
